@@ -1,9 +1,11 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
 import { Tooltip } from '@patternfly/react-core'
-import msgs from '../../../nls/platform.properties'
+import msgs from '../../nls/platform.properties'
 
 export const createDisableTooltip = (isDisabled, label, locale, component) => {
   // Tooltips will not show for disabled elements, so we need to wrap the element
