@@ -1,4 +1,6 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
@@ -7,17 +9,19 @@ import {
   ExclamationCircleIcon,
   ExclamationTriangleIcon,
   CheckCircleIcon,
+  OutlinedQuestionCircleIcon,
 } from '@patternfly/react-icons'
 import { Tooltip } from '@patternfly/react-core'
 import dangerColor from '@patternfly/react-tokens/dist/js/global_danger_color_100'
 import okColor from '@patternfly/react-tokens/dist/js/global_palette_green_500'
 import warningColor from '@patternfly/react-tokens/dist/js/global_warning_color_100'
+import questionInfoColor from '@patternfly/react-tokens/dist/js/global_icon_Color_light'
 
 export const GreenCheckCircleIcon = ({tooltip}) => {
   if (tooltip) {
     return (
       <Tooltip content={<div>{tooltip}</div>}>
-        <CheckCircleIcon  color={okColor.value} />
+        <CheckCircleIcon color={okColor.value} />
       </Tooltip>
     )
   }
@@ -57,3 +61,19 @@ export const YellowExclamationTriangleIcon = ({tooltip}) => {
 YellowExclamationTriangleIcon.propTypes = {
   tooltip: PropTypes.string,
 }
+
+export const GrayOutlinedQuestionCircleIcon= ({tooltip, position}) => {
+  if (tooltip) {
+    return (
+      <Tooltip content={<div>{tooltip}</div>} position={position}>
+        <OutlinedQuestionCircleIcon color={questionInfoColor.value} />
+      </Tooltip>
+    )
+  }
+  return <OutlinedQuestionCircleIcon color={questionInfoColor.value} />
+}
+
+GrayOutlinedQuestionCircleIcon.propTypes = {
+  position: PropTypes.string,
+  tooltip: PropTypes.string,
+}
