@@ -1,9 +1,11 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import classNames from 'classnames'
 import React from 'react'
-import purifyReactNode from './PurifyReactNode'
+import purifyReactNode from '../../utils/PurifyReactNode'
 import PropTypes from 'prop-types'
 import {
   EmptyState,
@@ -21,20 +23,23 @@ import {
   SortByDirection
 } from '@patternfly/react-table'
 import { SearchIcon } from '@patternfly/react-icons'
-import resources from '../../../lib/shared/resources'
+import '../../scss/pattern-fly-table.scss'
 import moment from 'moment'
 
-resources(() => {
-  require('../../../scss/pattern-fly-table.scss')
-})
 class PatternFlyTable extends React.Component {
   constructor(props) {
     super(props)
-    const { searchValue, handleSearch, handleClear } = props
+    const { searchQueryEnabled, searchQueryKey, strictSearch } = props
+    let { searchValue } = props
     let searchText = ''
-    if (typeof handleSearch === 'function' && typeof handleClear === 'function' && typeof searchValue === 'string') {
-      searchText = searchValue.trim()
+    if (searchQueryEnabled) {
+      const searchQuery = new URLSearchParams(location.search.substring(1)).get(searchQueryKey)
+      // If there's a query, overwrite any provided searchValue
+      if (searchQuery) {
+        searchValue = searchQuery
+      }
     }
+    searchText = searchValue.trim()
     this.state = {
       perPage: this.props.perPage,
       page: 1,
@@ -43,7 +48,9 @@ class PatternFlyTable extends React.Component {
       sortBy: this.props.sortBy,
       startIdx: 0,
       endIdx: this.props.perPage,
-      searchState: searchText
+      searchState: searchText,
+      searchQueryEnabled,
+      strictSearch
     }
   }
   static defaultProps = {
@@ -51,11 +58,14 @@ class PatternFlyTable extends React.Component {
     perPage: 10,
     noResultMsg: 'No results found',
     searchable: true,
+    searchQueryEnabled: false,
+    searchQueryKey: 'searchFilter',
     searchPlaceholder: 'Find',
+    searchValue: '',
     sortBy: {}
   }
   static getDerivedStateFromProps(props, state) {
-    const { searchState, sortBy } = state
+    const { searchState, sortBy, strictSearch } = state
     const { searchValue, handleSearch, handleClear, pagination, rows, searchable } = props
     let trimmedSearchValue = typeof searchState === 'string' ? searchState.trim() : ''
     if (typeof handleSearch === 'function' && typeof handleClear === 'function' && typeof searchValue === 'string') {
@@ -85,6 +95,9 @@ class PatternFlyTable extends React.Component {
         return cells.some(item => {
           let parsedCell = parseCell(item)
           parsedCell = (typeof parsedCell === 'string') ? parsedCell : parsedCell.fromNow
+          if (strictSearch) {
+            return parsedCell.toLowerCase() === trimmedSearchValue.toLowerCase()
+          }
           return parsedCell.toLowerCase().includes(trimmedSearchValue.toLowerCase())
         })
       })
@@ -144,14 +157,27 @@ class PatternFlyTable extends React.Component {
     })
   }
   handleSearch = (value) => {
+    const { searchQueryKey } = this.props
+    const { searchQueryEnabled } = this.state
+    // Update URL query if it changes (without adding to browser history)
+    if (searchQueryEnabled) {
+      const searchQuery = new URLSearchParams(location.search.substring(1))
+      searchQuery.delete(searchQueryKey)
+      // If there are other queries, keep them in the URL, otherwise return the URL without queries
+      if (searchQuery.toString() !== '') {
+        window.history.replaceState({}, document.title, `${location.origin}${location.pathname}?${searchQuery.toString()}`)
+      } else {
+        window.history.replaceState({}, document.title, `${location.origin}${location.pathname}`)
+      }
+    }
     this.setState({
-      searchState: value
+      searchState: value,
+      searchQueryEnabled: false,
+      strictSearch: false
     })
   }
   handleClear = () => {
-    this.setState({
-      searchState: ''
-    })
+    this.handleSearch('')
   }
 
   render() {
@@ -257,6 +283,11 @@ PatternFlyTable.propTypes = {
   rows: PropTypes.array,
   /* Placeholder text for search input field */
   searchPlaceholder: PropTypes.string,
+  /* Enable updating the URL query for this table */
+  searchQueryEnabled: PropTypes.bool,
+  /* Key for URL query if enabled (in case there are
+    mutliple tables on a page or on differnt toggles) */
+  searchQueryKey: PropTypes.string,
   /* Initial search value from parent props */
   searchValue: PropTypes.string,
   /* Toggle search input (optional) */
@@ -266,6 +297,8 @@ PatternFlyTable.propTypes = {
     index: PropTypes.number,
     direction: PropTypes.oneOf(['asc', 'desc']),
   }),
+  /* Whether to match strings exactly */
+  strictSearch: PropTypes.bool,
   /* call back function to pass in and handle table action in patternfly table*/
   tableActionResolver: PropTypes.func
 }
