@@ -1,12 +1,14 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
 import { connect } from 'react-redux'
 import PropTypes from 'prop-types'
-import { Modal, Notification } from 'carbon-components-react'
-import { Spinner } from '@patternfly/react-core'
-import msgs from '../../../nls/platform.properties'
+import { AcmModal, AcmButton, AcmAlert } from '@open-cluster-management/ui-components'
+import { Spinner, ButtonVariant } from '@patternfly/react-core'
+import msgs from '../../nls/platform.properties'
 import { withRouter } from 'react-router-dom'
 import { REQUEST_STATUS } from '../../actions/index'
 import {
@@ -56,10 +58,10 @@ export class PolicyActionModal extends React.Component {
 
   render() {
     const { type:modalType, label, locale, open, reqErrorMsg, reqStatus } = this.props
-    let dangerFlag = false, modalId = '', modalMsg = ''
+    let warningFlag = 'default', modalId = '', modalMsg = ''
     switch(modalType) {
     case 'resource-disable':
-      dangerFlag = true
+      warningFlag = 'warning'
       modalId = 'disable-resource-modal'
       modalMsg = 'modal.disable.description'
       break
@@ -68,7 +70,7 @@ export class PolicyActionModal extends React.Component {
       modalMsg = 'modal.enable.description'
       break
     case 'resource-enforce':
-      dangerFlag = true
+      warningFlag = 'warning'
       modalId = 'enforce-resource-modal'
       modalMsg = 'modal.enforce.description'
       break
@@ -82,27 +84,33 @@ export class PolicyActionModal extends React.Component {
     return (
       <div>
         {reqStatus === REQUEST_STATUS.IN_PROGRESS && <Spinner className='patternfly-spinner' />}
-        <Modal
-          danger={dangerFlag}
+        <AcmModal
+          titleIconVariant={warningFlag}
+          variant='medium'
           id={modalId}
-          open={open}
-          primaryButtonText={msgs.get(label.primaryBtn, locale)}
-          secondaryButtonText={msgs.get('modal.button.cancel', locale)}
-          modalLabel={msgs.get(label.label, locale)}
-          modalHeading={msgs.get(label.heading, locale)}
-          onRequestClose={this.handleCloseClick}
-          onRequestSubmit={this.handleSubmitClick}
-          role='region'
-          aria-label={msgs.get(label.heading, locale)}>
+          isOpen={open}
+          showClose={true}
+          onClose={this.handleCloseClick}
+          title={msgs.get(label.heading, locale)}
+          actions={[
+            <AcmButton key="confirm" variant={ButtonVariant.primary} onClick={this.handleSubmitClick}>
+            {msgs.get(label.primaryBtn, locale)}
+            </AcmButton>,
+            <AcmButton key="cancel" variant={ButtonVariant.link} onClick={this.handleCloseClick}>
+            {msgs.get('modal.button.cancel', locale)}
+            </AcmButton>,
+          ]}
+        >
           <div>
             {reqStatus === REQUEST_STATUS.ERROR &&
-              <Notification
-                kind='error'
-                title=''
-                subtitle={reqErrorMsg || msgs.get('error.default.description', locale)} />}
+              <AcmAlert
+                isInline={true}
+                noClose={true}
+                variant='warning'
+                title={reqErrorMsg || msgs.get('error.default.description', locale)} />}
           </div>
-          <p>{msgs.get(modalMsg, locale)}</p>
-        </Modal>
+           {msgs.get(modalMsg, locale)}
+        </AcmModal>
       </div>
     )
   }
