@@ -1,4 +1,6 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
@@ -6,11 +8,11 @@ import PropTypes from 'prop-types'
 import {
   Title,
 } from '@patternfly/react-core'
-import PatternFlyTable from '../common/PatternFlyTable'
+import { AcmTable, AcmTablePaginationContextProvider } from '@open-cluster-management/ui-components'
 import { LocaleContext } from '../common/LocaleContext'
 import statusHistoryDef from '../../tableDefinitions/statusHistoryDef'
 import { transform } from '../../tableDefinitions/utils'
-import msgs from '../../../nls/platform.properties'
+import msgs from '../../nls/platform.properties'
 
 class PolicyStatusHistoryView extends React.Component {
   constructor(props) {
@@ -20,10 +22,10 @@ class PolicyStatusHistoryView extends React.Component {
   static contextType = LocaleContext
 
   render() {
-    const { history, cluster, template } = this.props
+    const { items=[], cluster, template } = this.props
     const { locale } = this.context
 
-    const tableData = transform(history, statusHistoryDef, locale)
+    const tableData = transform(items, statusHistoryDef, locale)
 
     return (
       <div className='policy-status-history-view'>
@@ -31,7 +33,16 @@ class PolicyStatusHistoryView extends React.Component {
           <Title className='title' headingLevel="h3">{cluster}</Title>
           <Title className='title' headingLevel="h4">{`${msgs.get('policy.template', locale)}: ${template}`}</Title>
           <br></br>
-          <PatternFlyTable {...tableData} noResultMsg={msgs.get('table.search.no.results', locale)} />
+          <AcmTablePaginationContextProvider localStorageKey='grc-status-history'>
+            <AcmTable
+              items={tableData.rows}
+              columns={tableData.columns}
+              keyFn={(item) => item.uid.toString()}
+              initialSort={tableData.sortBy}
+              gridBreakPoint=''
+              plural={'history'}
+            />
+          </AcmTablePaginationContextProvider>
         </div>
       </div>
 
@@ -41,7 +52,7 @@ class PolicyStatusHistoryView extends React.Component {
 
 PolicyStatusHistoryView.propTypes = {
   cluster: PropTypes.string,
-  history: PropTypes.array,
+  items: PropTypes.array,
   template: PropTypes.string
 }
 
