@@ -7,9 +7,10 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 const path = require('path'),
       webpack = require('webpack'),
-      TerserPlugin = require('terser-webpack-plugin'),
       AssetsPlugin = require('assets-webpack-plugin'),
       CompressionPlugin = require('compression-webpack-plugin')
 
@@ -17,12 +18,9 @@ const PRODUCTION = process.env.BUILD_ENV ? /production/.test(process.env.BUILD_E
 
 process.env.BABEL_ENV = process.env.BABEL_ENV ? process.env.BABEL_ENV : 'client'
 
-const overpassTest = /overpass-.*\.(woff2?|ttf|eot|otf)(\?.*$|$)/
-
 module.exports = {
   entry: {
     'vendorhcm': [
-      'carbon-components-react',
       '@loadable/component',
       'lodash',
       'moment',
@@ -30,14 +28,13 @@ module.exports = {
       'prop-types',
       'react-dom',
       'react-dom/server',
-      'react-monaco-editor',
       'react-redux',
       'react-router-dom',
       'react',
       'redux-logger',
       'redux-thunk',
       'redux',
-      'reselect',
+      'reselect'
     ]
   },
 
@@ -49,21 +46,6 @@ module.exports = {
         use: [{ loader: 'style-loader', options: { base: 2000 } },
           'css-loader',],
       },
-      {
-        test: /\.(woff2?|ttf|eot|otf)(\?.*$|$)/,
-        exclude: overpassTest,
-        loader: 'file-loader',
-        options: {
-          name: 'assets/[name].[ext]',
-        },
-      },
-      {
-        // Resolve to an empty module for overpass fonts included in SASS files.
-        // This way file-loader won't parse them. Make sure this is BELOW the
-        // file-loader rule.
-        test: overpassTest,
-        loader: 'null-loader',
-      },
     ],
   },
 
@@ -73,13 +55,6 @@ module.exports = {
     library: '[name]'
   },
 
-  optimization: {
-    minimize: PRODUCTION,
-    minimizer: [new TerserPlugin({
-      parallel: true,
-    })],
-  },
-
   plugins: [
     new webpack.DefinePlugin({
       'process.env': {
@@ -92,9 +67,9 @@ module.exports = {
       context: __dirname
     }),
     new CompressionPlugin({
-      filename: '[path].gz',
+      filename: '[path][base].gz',
       algorithm: 'gzip',
-      test: /\.js$|\.css$|\.html$/,
+      test: /\.js$|\.css$|\.html$/
     }),
     new AssetsPlugin({
       path: path.join(__dirname, 'public'),
